diff --git a/picture.go b/picture.go
index fa6eb304a223da9c2e4917f0d6948018317a6551..97cc61b8348bac76e250361182650103c430d516 100644
--- a/picture.go
+++ b/picture.go
@@ -20,12 +20,12 @@ type Picture struct {
 
 // NewPicture creates a new picture from an image.Image.
 func NewPicture(img image.Image, smooth bool) *Picture {
-	// convert the image to RGBA format
-	var rgba *image.RGBA
-	if rgbaImg, ok := img.(*image.RGBA); ok {
+	// convert the image to NRGBA format
+	var rgba *image.NRGBA
+	if rgbaImg, ok := img.(*image.NRGBA); ok {
 		rgba = rgbaImg
 	} else {
-		rgba = image.NewRGBA(image.Rect(0, 0, img.Bounds().Dx(), img.Bounds().Dy()))
+		rgba = image.NewNRGBA(image.Rect(0, 0, img.Bounds().Dx(), img.Bounds().Dy()))
 		draw.Draw(rgba, rgba.Bounds(), img, img.Bounds().Min, draw.Src)
 	}